@@ -283,6 +283,7 @@ class CallbackInput(BaseDictKey):
 class ExtractFullTextInput(BaseDictKey):
     cid: str
     callback: CallbackInput
+    useArchivalCopy: bool = True
 
     def validate(self):
         errors = []
@@ -308,6 +309,6 @@ class SetArchivalCopyUrlInput(BaseDictKey):
             errors.append('Invalid cid format. Must be 20.500.12592/abcdef')
         errors = []
         parse_res = urlparse(self.url)
-        if parse_res.scheme not in ['http', 'https', 's3']:
+        if parse_res.scheme not in ['http', 'https']:
             errors.append('URL is invalid')
         return errors
